#[non_exhaustive]pub enum ParseError {
LimitExceeded {
limit: &'static str,
},
ArithmeticOverflow {
context: &'static str,
},
Malformed {
message: BoundedText,
},
MissingObject {
message: BoundedText,
},
UnsupportedFilter {
filter: BoundedText,
},
StreamDecode {
message: BoundedText,
},
}Expand description
Parser-specific error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LimitExceeded
A configured parser resource limit was exceeded.
ArithmeticOverflow
Checked arithmetic overflowed while processing input.
Malformed
PDF syntax could not be recovered.
Fields

message: BoundedTextBounded diagnostic message.
MissingObject
A referenced object was missing or had the wrong shape.
Fields

message: BoundedTextBounded diagnostic message.
UnsupportedFilter
A stream filter is not supported by this phase.
Fields

filter: BoundedTextFilter name.
StreamDecode
Stream decoding failed.
Fields

message: BoundedTextBounded diagnostic message.