#[non_exhaustive]pub enum PolicyOperator {
Exists,
Absent,
Equals,
NotEquals,
Min,
Max,
}Expand description
Bounded policy comparison operator.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Exists
At least one matching feature object contains the field.
Absent
No matching feature object contains the field.
Equals
At least one matching value equals the rule value.
NotEquals
No matching value equals the rule value.
Min
At least one matching numeric value is greater than or equal to the rule value.
Max
At least one matching numeric value is less than or equal to the rule value.