RepairReport

Struct RepairReport 

#[non_exhaustive]
pub struct RepairReport { pub engine_version: String, pub source: InputSummary, pub output_path: Option<PathBuf>, pub status: RepairStatus, pub actions: Vec<RepairAction>, pub refusal: Option<RepairRefusal>, pub warnings: Vec<ValidationWarning>, pub task_durations: Vec<TaskDuration>, }
Metadata repair report for one input.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
engine_version: String

Engine version that produced the report.

source: InputSummary

Input summary.

output_path: Option<PathBuf>

Optional output path when a repaired or unchanged file was written.

status: RepairStatus

Overall repair status.

actions: Vec<RepairAction>

Actions completed for this input.

refusal: Option<RepairRefusal>

Refusal reason when no output was produced.

warnings: Vec<ValidationWarning>

User-visible repair warnings.

task_durations: Vec<TaskDuration>

Task duration measurements.

Implementations

Source

impl RepairReport

pub fn builder() -> RepairReportBuilder<((), (), (), (), (), (), (), ())>

Create a builder for building RepairReport. On the builder, call .engine_version(...), .source(...), .output_path(...), .status(...), .actions(...), .refusal(...), .warnings(...), .task_durations(...) to set the values of the fields. Finally, call .build() to create the instance of RepairReport.

Source

impl RepairReport

pub fn wrote_output(&self) -> bool

Returns true when the report describes a written output file.