#[non_exhaustive]pub struct ValidationOptions {
pub flavour: FlavourSelection,
pub resource_limits: ResourceLimits,
pub password: Option<PasswordSecret>,
pub max_failed_assertions_per_rule: MaxDisplayedFailures,
pub record_passed_assertions: bool,
pub report_parse_warnings: bool,
pub feature_selection: FeatureSelection,
pub policy: Option<PolicySet>,
}Expand description
PDF validation options shared by parser, engine, and reports.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.flavour: FlavourSelectionFlavour/profile selection policy.
resource_limits: ResourceLimitsParser and validation resource limits.
password: Option<PasswordSecret>Optional redacted password for encrypted PDFs.
max_failed_assertions_per_rule: MaxDisplayedFailuresMaximum assertion details retained per failed rule.
record_passed_assertions: boolWhether passed assertion details are recorded.
report_parse_warnings: boolWhether recoverable parser warnings are included in the report.
feature_selection: FeatureSelectionOptional feature families to extract into reports.
policy: Option<PolicySet>Optional feature-policy rules to evaluate.
Implementations
Sourceimpl ValidationOptions
impl ValidationOptions
Sourcepub fn builder() -> ValidationOptionsBuilder<((), (), (), (), (), (), (), ())>
pub fn builder() -> ValidationOptionsBuilder<((), (), (), (), (), (), (), ())>
Create a builder for building ValidationOptions.
On the builder, call .flavour(...)(optional), .resource_limits(...)(optional), .password(...)(optional), .max_failed_assertions_per_rule(...)(optional), .record_passed_assertions(...)(optional), .report_parse_warnings(...)(optional), .feature_selection(...)(optional), .policy(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of ValidationOptions.