#[non_exhaustive]pub enum BuiltinFunction {
HasParseFact,
Size,
IsEmpty,
Contains,
All,
Exists,
Matches,
}Expand description
Bounded built-in function.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
HasParseFact
Returns true when a named parse fact exists.
Size
Returns collection or string size.
IsEmpty
Returns true when a collection or string is empty.
Contains
Returns true when a collection or string contains a value.
All
Returns true when every boolean argument is true.
Exists
Returns true when any boolean argument is true.
Matches
Returns true when a bounded regex matches a string.