#[non_exhaustive]pub enum ProfileError {
UnsupportedSelection,
InvalidField {
field: &'static str,
reason: BoundedText,
},
BudgetExceeded {
budget: &'static str,
},
UnknownProperty {
property: BoundedText,
},
TypeMismatch {
message: BoundedText,
},
UnsupportedRule {
reason: BoundedText,
},
InvalidXml {
reason: BoundedText,
},
}Expand description
Profile-specific error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsupportedSelection
Profile selection did not resolve to a supported profile.
InvalidField
A profile field failed validation.
BudgetExceeded
A rule expression exceeded a configured evaluation budget.
UnknownProperty
A rule referenced a property that does not exist on the model object.
Fields

property: BoundedTextProperty name.
TypeMismatch
A rule expression had a type mismatch.
Fields

message: BoundedTextBounded diagnostic message.
UnsupportedRule
A rule expression is not supported by the bounded IR.
Fields

reason: BoundedTextBounded reason string.
InvalidXml
Profile XML failed bounded parsing.
Fields

reason: BoundedTextBounded reason string.