pub struct PasswordSecret(/* private fields */);Expand description
Redacted PDF password secret.
Implementations
Sourceimpl PasswordSecret
impl PasswordSecret
Sourcepub fn new(value: impl Into<String>) -> Result<Self, ConfigError>
pub fn new(value: impl Into<String>) -> Result<Self, ConfigError>
Creates a password secret using the default password byte cap.
Errors
Returns ConfigError when the password exceeds the default cap.
Sourcepub fn new_with_limit(
value: impl Into<String>,
max_bytes: usize,
) -> Result<Self, ConfigError>
pub fn new_with_limit( value: impl Into<String>, max_bytes: usize, ) -> Result<Self, ConfigError>
Creates a password secret using an explicit byte cap.
Errors
Returns ConfigError when the password exceeds the supplied cap or the
cap is above the hard limit.